/* This is part of tmview, a dvi previewer. (c) 1995 Thomas Moor         */
/*                                                                       */
/* This program may be used without any warranty. It may be modified and */
/* distributed without any restrictions.                                 */

void dvibad(char*);
void initfontdatabase(void);
void killfontdatabase(void);
int searchfontdatabase(char* , char*, long, long, long);
int allocfontdesc(char*, char*, long, long, long);
int  getintnr(long fontnr);
void initdvi(void);
void killdvi(void);
int testdvi(void);
void readpage(pagelistelement*);
short gotocccpage(double*,short);
const char* searchdvi(char* sstr, int* spage, long* spos);
